@@ -22,10 +22,10 @@ namespace WideMargin.Database
 {
 	public class SearchPageResult
 	{
-		public SearchPageResult (IEnumerable<IVerse> verses, int totalMatches, int pageSize, int pageNumber, string searchText)
+		public SearchPageResult (IEnumerable<IVerse> verses, IDictionary<string, int> matches, int pageSize, int pageNumber, string searchText)
 		{
 			Verses = verses;
-			TotalMatches = totalMatches;
+			Matches = matches;
 			PageSize = pageSize;
 			PageNumber = pageNumber;
 			SearchText = searchText;
@@ -37,7 +37,7 @@ namespace WideMargin.Database
 			private set;
 		}
 		
-		public int TotalMatches
+		public IDictionary<string, int> Matches
 		{
 			get;
 			private set;
