@@ -35,6 +35,11 @@ namespace WideMargin.MVCInterfaces
 		/// Occurs when a verse link is clicked.
 		/// </summary>
 		event EventHandler<LinkClickedEventArgs<IVerseIdentifier>> VerseLinkClicked;
+		
+		/// <summary>
+		/// Occurs when a action link is clicked.
+		/// </summary>
+		event EventHandler<LinkClickedEventArgs<string>> ActionLinkClicked;
 	}
 }
 
