@@ -19,13 +19,28 @@ using System.Collections.Generic;
 
 namespace WideMargin.MVCInterfaces
 {
-	public interface ISearchResultsView
+	/// <summary>
+	/// Interface for a view which shows search results.
+	/// </summary>
+	public interface ISearchResultsView : IFilteredView
 	{
-		void ShowResults(IEnumerable<IVerse> verses, int numberOfPages, int currentPage);
+		/// <summary>
+		/// Clears out all the displayed results
+		/// </summary>
+		void Clear();
 		
-		event EventHandler<PageRequestEventArgs> PageRequest;
+		/// <summary>
+		/// Appends results to the end of the view.
+		/// </summary>
+		/// <param name='verses'>Verses.</param>
+		void AppendResults(IEnumerable<IVerse> verses);
+
+		void SetResults(IEnumerable<IVerse> verses, IEnumerable<Filter> filters);
 		
-		event EventHandler<LinkClickedEventArgs<IVerseIdentifier>> VerseLinkActivated;
+		/// <summary>
+		/// Occurs when the view requires more search results
+		/// </summary>
+		event EventHandler<EventArgs> MoreResultsRequired;
 	}
 }
 
